
set echo on

CREATE TABLE tracefiles_xt
( permissions      VARCHAR2(10)
, links            NUMBER
, owner            VARCHAR2(30)
, group_name       VARCHAR2(30)
, bytes            NUMBER
, mon              VARCHAR2(3)
, day              NUMBER
, hhmi_or_yyyy     VARCHAR2(5)
, file_name        VARCHAR2(255)
)
ORGANIZATION EXTERNAL
(
  TYPE ORACLE_LOADER
  DEFAULT DIRECTORY trace_dir
  ACCESS PARAMETERS
  (
     RECORDS DELIMITED BY NEWLINE
     NOBADFILE
     NOLOGFILE
     PREPROCESSOR bin_dir: 'tracefiles.sh'
     FIELDS TERMINATED BY WHITESPACE
  )
  LOCATION (bin_dir:'tracefiles_xt.txt')
)
REJECT LIMIT UNLIMITED;

CREATE OR REPLACE VIEW tracefiles_vxt
AS
   SELECT permissions
   ,      owner
   ,      group_name
   ,      bytes
   ,      TO_DATE(mon || TO_CHAR(day, 'fm09') || hhmi_or_yyyy, 
                  'MonDD' || CASE
                                WHEN hhmi_or_yyyy LIKE '%:%'
                                THEN 'HH24:MI'
                                ELSE 'YYYY'
                             END) AS file_date
   ,      file_name
   FROM   tracefiles_xt
   WHERE  permissions NOT LIKE 'd%';

set lines 150
col permissions format a11
col owner format a10
col group_name format a10
col file_name format a40

SELECT *
FROM   tracefiles_vxt
WHERE  file_name LIKE '%.trc'
ORDER  BY
       file_date;

